<div align="center">

# Anti Flash

<!-- prettier-ignore-start -->
<!-- markdownlint-disable-next-line MD036 -->
_🎇 反闪照 🎇_
<!-- prettier-ignore-end -->

</div>
<p align="center">
  
  <a href="https://github.com/KafCoppelia/nonebot_plugin_antiflash/blob/main/LICENSEE">
    <img src="https://img.shields.io/badge/license-MIT-informational">
  </a>
  
  <a href="https://github.com/nonebot/nonebot2">
    <img src="https://img.shields.io/badge/nonebot2-2.0.0beta.1-green">
  </a>
  
  <a href="">
    <img src="https://img.shields.io/badge/release-v0.2.0-orange">
  </a>
  
</p>

</p>

## 版本

v0.2.0

⚠ 适配nonebot2-2.0.0beta.1；适配alpha.16版本参见[alpha.16分支](https://github.com/KafCoppelia/nonebot_plugin_antiflash/tree/alpha.16)

## 安装

1. 通过`pip`或`nb`安装，版本请指定`^0.2.0`；

2. 在`env`内设置：

```python
ANTI_FLASH_ON=true                          # 开启或关闭
ANTI_FLASH_GROUP=["123456789", "987654321"] # 指定群聊
```

## 功能

⚠ **谨慎开启此项功能, 谨慎指定群聊**

由于该功能过于危险，需指定特定群聊启用反闪照功能。

## 本插件改自

忘记出处了，找到了马上补上。